@@ -76,9 +76,6 @@ struct _dom_binding {
 	long int dom_vers;
 	int dom_lockfd;
 	int dom_alive;
-#ifdef __linux__
-	time_t timestamp; /* Last time seen alive */
-#endif
 	int dom_broadcast_pid;
 	int dom_pipe_fds[2];
 	int dom_default;
@@ -214,17 +211,6 @@ CLIENT *clnt;
 	}
 
 	if (ping(ypdb)) {
-#ifdef __linux__
-		/*
-		 * The Linux library will retry if it can't connect
-		 * to the server. We only return failure if we haven't
-		 * succeeded binding to a server for some time.
-		 *
-		 * This isn't perfect (the lib will print some timeout
-		 * errors) but at least it's transparent to the application.
-		 */
-		if (time(NULL) > ypdb->timestamp + FAIL_THRESHOLD * 2)
-#endif
 		return &res;
 	}
 
@@ -356,16 +342,6 @@ int sig;
 		children--;
 }
 
-#ifdef __linux__
-void gothit(sig)
-int sig;
-{
-	syslog(LOG_ERR, "got hit by signal %d - dying.\n");
-	signal(sig, SIG_DFL);
-	kill(getpid(), sig);
-}
-#endif
-
 void terminate(sig)
 int sig;
 {
@@ -491,15 +467,6 @@ char **argv;
 
 	signal(SIGCHLD, reaper);
 	signal(SIGTERM, terminate);
-#ifdef __linux__
-	signal(SIGPIPE, gothit);
-	signal(SIGILL,  gothit);
-	signal(SIGBUS,  gothit);
-	signal(SIGFPE,  gothit);
-	signal(SIGPIPE, gothit);
-	signal(SIGALRM, gothit);
-	signal(SIGIO,   gothit);
-#endif
 
 	openlog(argv[0], LOG_PID, LOG_DAEMON);
 
@@ -740,9 +707,6 @@ struct _dom_binding *ypdb;
 		YPPROG, YPVERS, interval, &rpcsock, RPCSMALLMSGSIZE,
 		RPCSMALLMSGSIZE)) == (CLIENT *)NULL) {
 		/* Can't get a handle: we're dead. */
-#ifdef __linux__
-		if (ypdb->dom_alive) ypdb->timestamp = time(NULL);
-#endif
 		ypdb->dom_alive = 0;
 		ypdb->dom_vers = -1;
 		broadcast(ypdb);
@@ -752,18 +716,13 @@ struct _dom_binding *ypdb;
 	if ((stat = clnt_call(client_handle, YPPROC_DOMAIN,
 		xdr_domainname, (char *)ypdb->dom_domain, xdr_bool,
 		(char *)&out, timeout)) != RPC_SUCCESS || out == FALSE) {
-#ifdef __linux__
-		if (ypdb->dom_alive) ypdb->timestamp = time(NULL);
-#endif
 		ypdb->dom_alive = 0;
 		ypdb->dom_vers = -1;
 		clnt_destroy(client_handle);
 		broadcast(ypdb);
 		return(1);
 	}
-#ifdef __linux__
-	ypdb->timestamp = time(NULL);
-#endif
+
 	clnt_destroy(client_handle);
 	return(0);
 }
@@ -864,9 +823,7 @@ int force;
 	ypdb->dom_vers = YPVERS;
 	ypdb->dom_alive = 1;
 	ypdb->dom_broadcast_pid = 0;
-#ifdef __linux__
-	ypdb->timestamp = time(NULL);
-#endif
+
 	if(ypdb->dom_lockfd != -1)
 		close(ypdb->dom_lockfd);
 
