@@ -25,7 +25,7 @@
 **         Thorsten Kukuk <kukuk@uni-paderborn.de>
 */
 
-static char rcsid[] = "$Id: server.c,v 1.19 1996/04/09 21:45:48 kukuk Exp $";
+static char rcsid[] = "$Id: server.c,v 1.0.4.1 1996/07/14 15:10:45 kukuk Exp $";
 
 #if defined(HAVE_CONFIG_H)
 #include "config.h"
@@ -744,6 +744,18 @@ ypresp_key_val *ypproc_next_2_svc(ypreq_key *key, struct svc_req *rqstp)
 	  
 	  result.stat = read_database(dbp, &dkey, &okey, &dval, 
 				      F_NEXT, mangle_field);
+	  /*
+	  ** If the key is empty, get the next one, until we
+	  ** get a key which is not empty
+	  */
+	  while ((okey.dsize == 0) && (result.stat == YP_TRUE))
+	    {
+	      dkey.dsize = okey.dsize;
+	      dkey.dptr = okey.dptr;
+
+	      result.stat = read_database(dbp, &dkey, &okey, &dval, 
+					  F_NEXT, mangle_field);
+	    }
 
 	  if (result.stat == YP_TRUE)
 	    {
@@ -814,7 +826,7 @@ ypresp_xfr *ypproc_xfr_2_svc(ypreq_xfr *xfr, struct svc_req *rqstp)
   if(!is_valid_domain(xfr->map_parms.domain))
     {
       if(debug_flag)
-	yp_msg("\t-> Ignored (not a vald domain)\n");
+	yp_msg("\t-> Ignored (not a valid domain)\n");
 
       result.xfrstat = YPXFR_NODOM;
       return &result;
@@ -918,6 +930,18 @@ static int ypall_encode(ypresp_key_val *val, void *data)
   val->stat = read_database(((ypall_data_t)data)->dbm, &dkey, &okey, &dval, 
 			    F_NEXT, ((ypall_data_t)data)->field);
   
+  /*
+  ** If key is empty, search the next one which is not empty
+  */
+  while ((okey.dsize == 0) && (val->stat == YP_TRUE))
+    {
+      dkey.dptr = okey.dptr;
+      dkey.dsize = okey.dsize;
+
+      val->stat = read_database(((ypall_data_t)data)->dbm, &dkey, &okey, &dval,
+				F_NEXT, ((ypall_data_t)data)->field);
+    }
+
   if (val->stat == YP_TRUE)
     {
       val->key.keydat_val = okey.dptr;
