@@ -1,16 +1,17 @@
-/*  LAST EDIT: Thu Mar 14 14:38:06 1996 by Thorsten Kukuk (kukuk) */
 /* 
-**  $Id: ypxfr.h,v 1.1 1996/03/16 14:35:38 kukuk Exp $
+**  $Id: ypxfr.h,v 1.0.4.1 1996/07/14 15:10:45 kukuk Exp $
 */
 
-
 #ifndef __YPXFR_H__
 #define __YPXFR_H__
 
 #include "system.h"
 
 extern int __yp_master( char *DomainName, char *MapName, char **OutMaster);
+#if !defined(__NetBSD__)
+/* This is already defined in /usr/include/rpcsvc/ypclnt.h as unsigned int */
 extern int ypprot_err( long int );
+#endif
 extern int __yp_all( char *, char *, struct ypall_callback *);
 extern int ypbind_host(struct sockaddr_in *, char *);
 extern int _yp_clear(char *);
